==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/inputs/SelfHostedServerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin.inputs

import com.pulumi.azurenative.servicelinker.inputs.SelfHostedServerArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The service properties when target service type is SelfHostedServer
 * @property endpoint The endpoint of service.
 * @property type The target service type.
 * Expected value is 'SelfHostedServer'.
 */
public data class SelfHostedServerArgs(
    public val endpoint: Output<String>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.servicelinker.inputs.SelfHostedServerArgs> {
    override fun toJava(): com.pulumi.azurenative.servicelinker.inputs.SelfHostedServerArgs =
        com.pulumi.azurenative.servicelinker.inputs.SelfHostedServerArgs.builder()
            .endpoint(endpoint?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SelfHostedServerArgs].
 */
@PulumiTagMarker
public class SelfHostedServerArgsBuilder internal constructor() {
    private var endpoint: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value The endpoint of service.
     */
    @JvmName("pnntvtccunugqpyx")
    public suspend fun endpoint(`value`: Output<String>) {
        this.endpoint = value
    }

    /**
     * @param value The target service type.
     * Expected value is 'SelfHostedServer'.
     */
    @JvmName("kxfnqjaoislfavuh")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The endpoint of service.
     */
    @JvmName("swwpbaxpksxqdgnu")
    public suspend fun endpoint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endpoint = mapped
    }

    /**
     * @param value The target service type.
     * Expected value is 'SelfHostedServer'.
     */
    @JvmName("muapfoeajlxoeuwn")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): SelfHostedServerArgs = SelfHostedServerArgs(
        endpoint = endpoint,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/inputs/SelfHostedServerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin.inputs

import com.pulumi.azurenative.servicelinker.inputs.SelfHostedServerArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The service properties when target service type is SelfHostedServer
 * @property endpoint The endpoint of service.
 * @property type The target service type.
 * Expected value is 'SelfHostedServer'.
 */
public data class SelfHostedServerArgs(
    public val endpoint: Output<String>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.servicelinker.inputs.SelfHostedServerArgs> {
    override fun toJava(): com.pulumi.azurenative.servicelinker.inputs.SelfHostedServerArgs =
        com.pulumi.azurenative.servicelinker.inputs.SelfHostedServerArgs.builder()
            .endpoint(endpoint?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SelfHostedServerArgs].
 */
@PulumiTagMarker
public class SelfHostedServerArgsBuilder internal constructor() {
    private var endpoint: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value The endpoint of service.
     */
    @JvmName("ffurutbceyievjvr")
    public suspend fun endpoint(`value`: Output<String>) {
        this.endpoint = value
    }

    /**
     * @param value The target service type.
     * Expected value is 'SelfHostedServer'.
     */
    @JvmName("wbiomprnotcrjkob")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The endpoint of service.
     */
    @JvmName("gbuknsdfnfqoidbn")
    public suspend fun endpoint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endpoint = mapped
    }

    /**
     * @param value The target service type.
     * Expected value is 'SelfHostedServer'.
     */
    @JvmName("kdldklvbafamgujj")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): SelfHostedServerArgs = SelfHostedServerArgs(
        endpoint = endpoint,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
